==> ZenTaoPMS.16.5.php5.3_5.6.zip: zentaopms/extension/biz/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPoFsSoeVKaWENa7c2MGh0g6mI41ppKxw2VzN8rC2gu4eVz5EfYALJfB+8rqEBu4qE4r77inY
azViaBbH6s2naCzor6qbsvBx4WEPOptJJjvVD7pqAzvXCDl667hPupPEWSoR5CghZR3IePDCrxVd
1awp+qXTb++MkFGJeszFfRdG01wFqUxoWZq03r40o8k1iSWaa+do6tDreFF+IrD9EQCuXisENObg
zVurAcXUpDXjZbCRtVzRpbLDq3cwNuM9iE33M+i0jnCQOyVCkyPfpoER3MSxGfBUEBkgEa+IdaCm
UvTsZBEqrwQTg9jjNMOO4a0gu0rqCcjO+hHnM74+uFptRhqrrgd3ugQ3xp9v3P+BeIp9twXIuC1I
pMxtOe/BQ2o8/C/Pn9+9lVUYVnN/E5D75yI84RE4/WkT/N9sI8quGf9WxIfqapKlwnQXMoEAZ3uS
4nMIyRzimwxDc/AgPxQqdo03nTINUpDOcJX4joWKafiXbNvxebhW69mWDnVZO7nhuWj8gFnOPNxB
eABbUfKjKyN8JvMYr4+z4IaRrqFnTduSCyz2M5U/HnMyEUJseUgFWaEXN/ysp31GqGrl8JZOggxA
R7wQ9ndvKaUaFbEu9n4PFxh9ciyMvvN+uR/fI6bIS43ezvsnJIzpLjYVZZ+VVucmFh1U0pqWPrPm
YaJysPgxRkTzCkVs/vtxiVaQXGjCCcKpStGgxK8ipL/JL42NVD4oym+GbWmUPEtiEtvwsrXnAE7g
BDYqlryRn2S11QQUr8xe/QTUe4rMo2oEkqH4ipuU8j/zafTv6jnzkGIsPZXkd3/+1Pvf+RYEnPjz
Ge7nXejWmO5CvEEwNGrQEgKdsZb3XkuCxTUkKwPmVB4GtSMR6L7tz2yCREevzzMrhKYRq4opvQ5d
uwvDL7gRWIju8YGwzyH5W8HWoh2L/uACujcGpk/LiUH+GJxFIn8hmyI0DFEU166BGbtB+Kl4Y5xV
KCw8tdW9tCeikJh8y0wYPt1bwiG8KmMELsVdc+BUKaX2f4kmLutsJF1gqsioWWryhJlz7aNnYYHT
RqO4Joxrn5Hm8lazPqNhYtWu1zhTbLa6WhfPj5xh8/QIUzozv5beWiLOKLcwERHim7WoG6uwJqUr
kPWi+7NOsT6py0juRGnzHYHgBqB2jiU7rNbcljAJslXVz6B+Xy0N067JecNUf+dArfpV7zACkwzM
XeuoPVW/mkg35KfsPcK0NbGqLhLRg7jkIknFzc/VvzK7j1YcdgBprFBBzGF1hWmnb5nahXVizyAP
BrGatTgS9Qj7jxfzZ6BXtagNGaoBpge67MiJDlNGN5i8b8VP3vdnUKhSBXMzkklM0v7c8siK26q5
y2ZuukBCdZ/W++lo+fyrsWKebK50HC+zjM69yrdS2ddd3SIBeBR2ypCWI0h6g9IZxGzSv3xXC7Zh
tdOlXZq5yAlgi5z2Q/O3nUA6n2a2UUk8cTHk01v4BqATUg6W1Fw25ipHj5Hj/I9X1QUM66TqRgvQ
qKTV7npHP5JHFp2DzyuuLzrMNSvocDZ5uvol3yR1HOPB+3sWEgesswV1Pdk/DRgZGSzW4RvdworM
xMyiW6L7du57Nwz7QOy0qmHxQTG9AY6LiyDATf4hTncP0BJQadDC7YQRGSVo8R5088l6VGM+7mE7
vn0J6hXKLHjN+wwPTkdDjISn4k1s4Qxvx2Zm

==> ZenTaoPMS.17.1.php8.0.zip: zentaopms/extension/biz/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPw5uebHnmHQRkCmtT/c047eL1WL21ZNg3VeTMuB2xP10CQvN9Ie+pJ34q5Gt8CZsswkYiC2w
Y3rYzG7DA6uaivUaOaVVcKqRZoG030x6BOlb6lMVicGwatHi0LF1+xFyoN1cWhPBwlIwhivx/eYI
Pm5fEz3+8wdclzGhm6vfAwH9CCdZ8Cbq+mbpOflefDD1iFPHWKh12AEsP8LFEFrlRDxOxlUQqTIy
eExXrNchWq/GwPu353ZR2cJexzK25UoNYYBzavzlOoHFXzyrXm6urdce//OGc4SG6y23YTVRfkKj
3udWzBKbAP2wZ3AZQ6tOX5Yi4vJObgH4VLkpT1qWWLvUdJKMKeaq/OE/OxmGC2TtmbJb2VILkWN2
20+rkWkRWoZXIcvoESn21dMM2Ui0RV5TzublJ2RcrYqwuNIOMcPOOwu75JSF7Sno0SCFqu+ocBal
WlbXO9DZqeJ0KRwFnlRH8Co3vaCnOlp8CoLXVY3AaITxWKeRn6CTYXf4sz86QDuxrFDUcwKUQf5a
24vTn5b/OMnniHgTRUMx5ll/diM5SSDNTlj8/wbYsMvVWZefgMeGbNSTAl5wSGHQ/KaXTNfA3t7D
ZqCS2T3/AD5HljtJM0e0WA6CRk+14qIZJ9hd8lsNN0phRTPoUVhXmzYbogV5vFsh3Tibcc7Y4/8f
qpfWPH2ini9wuSiFat8d9gI5yUE3XF60GQjNsoOUsAbiSW9Z
